Gralkor.Graph (jido_gralkor v11.0.0)

Copy Markdown View Source

A complete graph payload supplied to the runtime-targeted Gralkor.Client.replace/2 boundary.

Nodes have unique string identifiers, string labels, and property maps. Relationships identify two supplied nodes, a type, and a property map.

Summary

Types

graph_node()

@type graph_node() :: %{
  id: String.t(),
  labels: [String.t()],
  properties: properties()
}

properties()

@type properties() :: %{optional(atom() | String.t()) => term()}

relationship()

@type relationship() :: %{
  from: String.t(),
  to: String.t(),
  type: String.t(),
  properties: properties()
}

t()

@type t() :: %Gralkor.Graph{nodes: [graph_node()], relationships: [relationship()]}