Gralkor.IngestedRepresentation (jido_gralkor v11.0.0)

Copy Markdown View Source

The successful result of storing content through one Lens.

Each representation has its own id and retains the Lens identity and content a consumer may supply to an explicitly invoked Reflection.

Summary

Types

t()

@type t() :: %Gralkor.IngestedRepresentation{
  content: String.t(),
  id: String.t(),
  lens: String.t(),
  result: :ok
}

Functions

new(lens, content)

@spec new(String.t(), String.t()) :: t()