Storage capability passed to a Gralkor.Lens.Ingestion process.
The Store is already bound to an operator and resolved Lens. Additions use an appending Lens's ontology and Destination; complete replacements use a replaceable Lens's fixed graph representation and ownership; searches use its Destination. Ingestion processes should use this capability rather than choose Graphiti group IDs themselves.
Global provenance is attached by the storage adapter and does not need to be supplied by the process.
Summary
Functions
Adds an episode through the bound Lens.
Replaces the complete graph owned by the bound replaceable Lens.
Searches the bound Lens's Destination graph.
Types
@type t() :: %Gralkor.Lens.Store{ lens: Gralkor.Lens.t() | Gralkor.Lens.Replaceable.t(), operator_id: String.t(), representation_collector: (Gralkor.IngestedRepresentation.t() -> any()) | nil, source_kind: Gralkor.Ingest.source_kind() | nil }
Functions
Adds an episode through the bound Lens.
@spec replace_graph(t(), Gralkor.Graph.t()) :: :ok | {:error, term()}
Replaces the complete graph owned by the bound replaceable Lens.
@spec search(t(), String.t(), pos_integer()) :: {:ok, [String.t()]} | {:error, term()}
Searches the bound Lens's Destination graph.