A complete graph payload supplied to Gralkor.Client.replace/1.
:property_graph nodes have unique string identifiers, string labels, and
property maps. Relationships identify two supplied nodes, a type, and a
property map.
Summary
Types
@type graph_node() :: %{ id: String.t(), labels: [String.t()], properties: properties() }
@type property_graph() :: %{nodes: [graph_node()], relationships: [relationship()]}
@type relationship() :: %{ from: String.t(), to: String.t(), type: String.t(), properties: properties() }
@type t() :: %Gralkor.Graph{data: property_graph(), format: :property_graph}