The successful result of storing content through one Lens.
Each representation has its own id and retains the Lens identity and content a consumer may supply to an explicitly invoked Reflection.
id
@type t() :: %Gralkor.IngestedRepresentation{ content: String.t(), id: String.t(), lens: String.t(), result: :ok }
@spec new(String.t(), String.t()) :: t()