Gralkor.IngestedRepresentation (jido_gralkor v7.0.0)

Copy Markdown View Source

The successful result of storing one piece of evidence through one Lens.

Multiple Lens representations of the same submitted information share an evidence_id; each representation has its own id and retains the Lens identity needed by post-ingestion Reflections.

Summary

Types

t()

@type t() :: %Gralkor.IngestedRepresentation{
  content: String.t(),
  evidence_id: String.t(),
  id: String.t(),
  lens: String.t(),
  result: :ok
}

Functions

new(evidence_id, lens, content)

@spec new(String.t(), String.t(), String.t()) :: t()

new_evidence_id()

@spec new_evidence_id() :: String.t()