Storage capability passed to a Gralkor.Lens.Ingestion process.
The Store is already bound to an operator and resolved Lens. Additions use an appending Lens's ontology and scope; complete replacements use a replaceable Lens's graph format and ownership; searches use its destination. Ingestion processes should use this capability rather than choose Graphiti group IDs themselves.
Global provenance is attached by the storage adapter and does not need to be supplied by the process.
Summary
Functions
Adds an episode through the bound Lens.
Replaces the complete graph owned by the bound replaceable Lens.
Searches the bound Lens's group.
Types
@type t() :: %Gralkor.Lens.Store{ evidence_id: String.t() | nil, lens: Gralkor.Lens.t() | Gralkor.Lens.Replaceable.t() | :global, operator_id: String.t(), representation_collector: (Gralkor.IngestedRepresentation.t() -> any()) | nil }
Functions
Adds an episode through the bound Lens.
@spec replace_graph(t(), Gralkor.Graph.t()) :: :ok | {:error, term()}
Replaces the complete graph owned by the bound replaceable Lens.
@spec search(t(), String.t(), pos_integer()) :: {:ok, [String.t()]} | {:error, term()}
Searches the bound Lens's group.